@@ -27,16 +27,14 @@ char *fmtgidname (gid_t gid)
 
   register char *szName;
     /* Pointer to name */
-  register struct group *stGroup;
-    /* Group entry */
 
   ENTER_FUNCTION("nqs_generic/all-systems/fmtgidname");
     /* debugging information */
   
-  stGroup = fetchgrgid (gid);
+  szName = getgrpnam(gid);
     /* Get group entry */
   
-  if (stGroup == NULL)
+  if ((szName = getgrpnam(gid)) == NULL)
   {
     /*
      *  No such group!  Format a "stand-in" name.
@@ -44,8 +42,6 @@ char *fmtgidname (gid_t gid)
     sprintf (szStandInBuf, "[%1d]", (int) gid);
     szName = szStandInBuf;
   }
-  else
-    szName = stGroup->gr_name;
   
   EXIT_FUNCTION;
   return (szName);
