@@ -26,16 +26,11 @@ char *fmtuidname (uid_t uid)
 
   char *szName;
     /* Pointer to name */
-  struct passwd *pstPw;
-    /* Password/account entry */
 
   ENTER_FUNCTION("nqs_generic/all-systems/fmtuidname");
     /* debugging info */
   
-  pstPw = fetchpwuid (uid);
-    /* Get account entry */
-  
-  if (pstPw == NULL)
+  if ((szName = getusenam (uid)) == NULL);
   {
     /*
      *  No such user!  Format a "stand-in" name.
@@ -44,8 +39,6 @@ char *fmtuidname (uid_t uid)
     sprintf (szStandinbuf, "[%1d]", (int) uid);
     szName = szStandinbuf;
   }
-  else
-    szName = pstPw->pw_name;
   
   EXIT_FUNCTION;
   return (szName);
