@@ -7,6 +7,9 @@
   /* NQS license information */
 #include <nqs_generic/debug.h>
   /* debugging information */
+#include <nqs_generic/proto.h>
+  /* ANSI C prototypes */
+
 #include <stdio.h>
   /* for NULL definition */
 
