@@ -12,6 +12,8 @@
 #include <nqs_queue/quolim.h>
   /* for struct quotalimit and quota limit units */
 
+#define BYTES_PER_WORD 4
+
 /*** secgrfir
  *
  *	int secgrfir():
@@ -30,11 +32,8 @@
  *	long is at least 32.  It is further assumed that first_quota
  *	and second_quota are each < 2**32.
  */
-int secgrfir (
-	unsigned long first_quota,
-	short first_units,
-	unsigned long second_quota,
-	short second_units)
+int secgrfir (unsigned long first_quota,  short first_units,
+	      unsigned long second_quota, short second_units)
 {
   ENTER_FUNCTION("nqs_generic/all-systems/secgrfir");
     /* debugging information */
